#[non_exhaustive]pub struct Config {
pub build_command: Vec<String>,
pub run_command: Vec<String>,
pub run_args: Option<Vec<String>>,
pub test_args: Option<Vec<String>>,
pub test_timeout: u32,
pub test_success_exit_code: Option<i32>,
pub test_no_reboot: bool,
}Expand description
Represents the package.metadata.bootimage configuration table
The bootimage crate can be configured through a package.metadata.bootimage table
in the Cargo.toml file of the kernel. This struct represents the parsed configuration
options.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.build_command: Vec<String>The cargo subcommand that is used for building the kernel for cargo bootimage.
Defaults to build.
run_command: Vec<String>The run command that is invoked on bootimage run or bootimage runner
The substring “{}” will be replaced with the path to the bootable disk image.
run_args: Option<Vec<String>>Additional arguments passed to the runner for not-test binaries
Applies to bootimage run and bootimage runner.
test_args: Option<Vec<String>>Additional arguments passed to the runner for test binaries
Applies to bootimage runner.
test_timeout: u32The timeout for running an test through bootimage test or bootimage runner in seconds
test_success_exit_code: Option<i32>An exit code that should be considered as success for test executables (applies to
bootimage runner)
test_no_reboot: boolWhether the -no-reboot flag should be passed to test executables
Defaults to true