pub fn run(
config: Config,
args: RunnerArgs,
image_path: &Path,
is_test: bool,
) -> Result<i32, RunError>Expand description
Run the given disk image in QEMU.
Automatically takes into account the runner arguments and the run/test
commands defined in the given Config. Since test executables are treated
differently (run with a timeout and match exit status), the caller needs to
specify whether the given disk image is a test or not.